==> ejc-salary-impl-3.0.0-20240920.090720-5-sources.jar: com/ejianc/business/salary/bean/RosterAttendanceEntity.java <==
package com.ejianc.business.salary.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 人员花名册-出勤
 * 
 * @author generator
 * 
 */
 @TableName("ejc_salary_roster_attendance")
public class RosterAttendanceEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="month")
    private Integer month; // 月份
    @TableField(value="should_day")
    private Integer shouldDay; // 应出勤天数
    @TableField(value="actual_day")
    private Integer actualDay; // 实际出勤天数
    @TableField(value="sync_day")
    private Long syncDay; // 同步日期
    @TableField(value="hr_id")
    private String hrId; // 人力主键
    @TableField(value="hr_state")
    private Integer hrState; // 人力状态（1：正常，2：删除）
    @TableField(value="employee_code")
    private String employeeCode; // 员工编码
    @TableField(value="id_card")
    private String idCard; // 身份证号
    
    
    

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public Integer getMonth() {
        return month;
    }

    public void setMonth(Integer month) {
        this.month = month;
    }
    public Integer getShouldDay() {
        return shouldDay;
    }

    public void setShouldDay(Integer shouldDay) {
        this.shouldDay = shouldDay;
    }
    public Integer getActualDay() {
        return actualDay;
    }

    public void setActualDay(Integer actualDay) {
        this.actualDay = actualDay;
    }
    public Long getSyncDay() {
        return syncDay;
    }

    public void setSyncDay(Long syncDay) {
        this.syncDay = syncDay;
    }
    public String getHrId() {
        return hrId;
    }

    public void setHrId(String hrId) {
        this.hrId = hrId;
    }
    public Integer getHrState() {
        return hrState;
    }

    public void setHrState(Integer hrState) {
        this.hrState = hrState;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    
}

==> ejc-salary-impl-3.0.0-20251112.100518-195-sources.jar: com/ejianc/business/salary/bean/RosterAttendanceEntity.java <==
package com.ejianc.business.salary.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 人员花名册-出勤
 * 
 * @author generator
 * 
 */
 @TableName("ejc_salary_roster_attendance")
public class RosterAttendanceEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="month")
    private Integer month; // 月份
    @TableField(value="should_day")
    private BigDecimal shouldDay; // 应出勤天数
    @TableField(value="actual_day")
    private BigDecimal actualDay; // 实际出勤天数
    @TableField(value="sync_day")
    private Long syncDay; // 同步日期
    @TableField(value="hr_id")
    private String hrId; // 人力主键
    @TableField(value="hr_state")
    private Integer hrState; // 人力状态（1：正常，2：删除）
    @TableField(value="employee_code")
    private String employeeCode; // 员工编码
    @TableField(value="id_card")
    private String idCard; // 身份证号
    
    
    

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public Integer getMonth() {
        return month;
    }

    public void setMonth(Integer month) {
        this.month = month;
    }
    public BigDecimal getShouldDay() {
        return shouldDay;
    }

    public void setShouldDay(BigDecimal shouldDay) {
        this.shouldDay = shouldDay;
    }
    public BigDecimal getActualDay() {
        return actualDay;
    }

    public void setActualDay(BigDecimal actualDay) {
        this.actualDay = actualDay;
    }
    public Long getSyncDay() {
        return syncDay;
    }

    public void setSyncDay(Long syncDay) {
        this.syncDay = syncDay;
    }
    public String getHrId() {
        return hrId;
    }

    public void setHrId(String hrId) {
        this.hrId = hrId;
    }
    public Integer getHrState() {
        return hrState;
    }

    public void setHrState(Integer hrState) {
        this.hrState = hrState;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    
}
